@@ -184,7 +184,7 @@ class CAM(object):
             for node in nodes:
                 nid = node['node']
                 #print(task_id, task, nid, node)
-                if (task['runhost'] is None or node['host'] in task['runhost']) and node['status'] in ['IDLE', 'FINISHED']:
+                if ('runhost' not in task or task['runhost'] is None or (node['host'] in task['runhost'])) and node['status'] in ['IDLE', 'FINISHED']:
                     msg = self._make_server_msg(type = "RUN", cmd = task['cmd'], task_id = task_id)
                     self._publish("to_%s"%nid, msg)
                     task['assigned_time'] = get_time()
